@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 import contextlib
-import json
 import math
 
 import pandas
@@ -9,11 +8,10 @@ from pytdx.hq import TdxHq_API
 from tqdm import tqdm
 from unipath import Path
 
-from mootdx import config
-from mootdx.consts import MARKET_SH, CONFIG
+from mootdx import config, server
+from mootdx.consts import MARKET_SH
 from mootdx.logger import log
-from mootdx.server import Server
-from mootdx.utils import get_stock_market, get_stock_markets, to_data, get_config_path
+from mootdx.utils import (get_config_path, get_stock_market, get_stock_markets, to_data)
 
 
 class Quotes(object):
@@ -35,23 +33,16 @@ class Quotes(object):
 class BaseQuotes(object):
     client = None
     bestip = None
-    timeout = 15
 
-    def __init__(self, bestip=False, **kwargs):
+    def __init__(self, bestip=False, timeout=15, **kwargs):
         log.debug(f'bestip=>{bestip}')
 
+        self.timeout = timeout
+
         config_ = get_config_path('config.json')
-        default = dict(CONFIG)
 
         if bestip or not Path(config_).exists():
-
-            for index in ['HQ', 'EX', 'GP']:
-                result = Server(index=index)
-
-                if result:
-                    default['BESTIP'][index] = result[0]
-
-            json.dump(default, open(config_, 'w'), indent=2)
+            server.bestip()
 
     @contextlib.contextmanager
     def connect(self):
@@ -90,8 +81,8 @@ class StdQuotes(BaseQuotes):
     """
     bestip = ('47.103.48.45', 7709)
 
-    def __init__(self, bestip=False, **kwargs):
-        super(StdQuotes, self).__init__(bestip=bestip, **kwargs)
+    def __init__(self, bestip=False, timeout=15, **kwargs):
+        super(StdQuotes, self).__init__(bestip=bestip, timeout=timeout, **kwargs)
 
         try:
             default = config.get('SERVER').get('HQ')[0]
@@ -387,8 +378,8 @@ class ExtQuotes(BaseQuotes):
 
     bestip = ('112.74.214.43', 7727)
 
-    def __init__(self, bestip=False, **kwargs):
-        super(ExtQuotes, self).__init__(bestip=bestip, **kwargs)
+    def __init__(self, bestip=False, timeout=15, **kwargs):
+        super(ExtQuotes, self).__init__(bestip=bestip, timeout=timeout, **kwargs)
 
         try:
             default = config.get('SERVER').get('EX')[0]
